@@ -73,7 +73,7 @@ int main(int argc, char **argv)
     int FD;
     int	NumFiles;
     bool Error, MinSizeFlag = false, HelpFlag = false;
-    char **FileName = NULL, FoutTmpName[STRLEN], FullPath[STRLEN], *p;
+    char **FileName = NULL, FoutTmpName[STRLEN+1], FullPath[STRLEN+1], *p;
     FILE *Fin, *Fout;
 
     if ((Error = GAGetArgs(argc, argv, CtrlStr, &GifNoisyPrint,
@@ -160,7 +160,8 @@ int main(int argc, char **argv)
 	fclose(Fout);
 	unlink(*FileName);
 	if (rename(FoutTmpName, *FileName) != 0) {
-	    char DefaultName[STRLEN];
+	    char DefaultName[STRLEN+1];
+	    memset(DefaultName, '\0', sizeof(DefaultName));
 	    if ( (strlen(FullPath) + strlen(DEFAULT_OUT_NAME)) > STRLEN-1 ) GIF_EXIT("Filename too long.");
 	    strncpy(DefaultName, FullPath, STRLEN);
 	    // cppcheck-suppress uninitstring
